@@ -116,6 +116,7 @@ class Action0Property(BaseAction0Property):
 # 'string', if set, means that the value of the property should be a string.
 # The value of characteristic indicates the string range to use (usually 0xD0 or 0xDC)
 # If set to None, the string will use the ID of the item (used for vehicle names)
+# It can also be a (threshold, below, above) tuple to select range depending on ID
 #
 # 'string_literal', if set, indicates that the value of the property should
 # be a literal (quoted) string. The value of the characteristic is equal to
@@ -155,6 +156,7 @@ class Action0Property(BaseAction0Property):
 # 'num' is the Action0 property number of the action 0 property, as given by the
 # nfo specs. If set to -1, no action0 property will be generated. If
 # 'custom_function' is set, this value is not needed and can be left out.
+# It can also be a (threshold, below, above) tuple to set 'num' depending on ID.
 #
 # 'size' is the size (in bytes) of the resulting action 0 property. Valid
 # values are 1 (byte), 2 (word) or 4 (dword). For other (or variable) sizes,
@@ -542,19 +544,39 @@ def speed_fraction(value):
     return nmlop.SUB(255, value).reduce()
 
 
+def ship_speed_prop(prop_info):
+    # prop 0B value is min(value, 255)
+    def prop0B_value(value):
+        return nmlop.MIN(value, 0xFF).reduce()
+
+    # prop 23 value is min(value, 65535)
+    def prop23_value(value):
+        return nmlop.MIN(value, 0xFFFF).reduce()
+
+    # prop 23 should not be set if value(prop0B_value) <= 255.
+    def prop23_test(value):
+        return isinstance(value, ConstantNumeric) and value.value >= 0xFF
+
+    prop0B = {"size": 1, "num": 0x0B, "value_function": prop0B_value}
+    prop23 = {"size": 2, "num": 0x23, "value_function": prop23_value, "test_function": prop23_test}
+    for key in prop_info:
+        prop0B[key] = prop23[key] = prop_info[key]
+    return [prop0B, prop23]
+
+
 # fmt: off
 properties[0x02] = {
     **general_veh_props,
     "sprite_id":                    {"size": 1, "num": 0x08},
     "is_refittable":                {"size": 1, "num": 0x09},
     "cost_factor":                  {"size": 1, "num": 0x0A},
-    "speed": {
-        "size": 1,
-        "num": 0x0B,
-        "unit_type": "speed",
-        "unit_conversion": (10000, 1397),
-        "adjust_value": lambda val, unit: ottd_display_speed(val, 1, 2, unit),
-    },
+    "speed": ship_speed_prop(
+        {
+            "unit_type": "speed",
+            "unit_conversion": (10000, 1397),
+            "adjust_value": lambda val, unit: ottd_display_speed(val, 1, 2, unit),
+        }
+    ),
     "default_cargo_type":           {"size": 1, "num": 0x0C},
     "cargo_capacity":               {"size": 2, "num": 0x0D},
     # 0E does not exist
@@ -595,6 +617,7 @@ properties[0x02] = {
     ],
     "variant_group":                {"size": 2, "num": 0x20},
     "extra_flags":                  {"size": 4, "num": 0x21},
+    "acceleration":                 {"size": 1, "num": 0x24},
 }
 # fmt: on
 
@@ -706,8 +729,8 @@ properties[0x04] = {
     # 19 (road routing) reserved for future use
     # 1A (advanced sprite layout) is implemented elsewhere
     # 1B (minimum bridge height) JGR only
-    "name":                  {"size": 2, "num": 0x1C, "string": (256, 0xC5, 0xDC), "required": True},
-    "classname":             {"size": 2, "num": 0x1D, "string": 0xDC},
+    "name":                  {"size": 2, "num": (256, -1, 0x1C), "string": (256, 0xC5, 0xDC), "required": True},
+    "classname":             {"size": 2, "num": (256, -1, 0x1D), "string": (256, 0xC4, 0xDC)},
 }
 # fmt: on
 
@@ -1240,6 +1263,8 @@ properties[0x0B] = {
     "units_of_cargo":            {"num": 0x1B, "size": 2, "string": 0xDC},
     "items_of_cargo":            {"num": 0x1C, "size": 2, "string": 0xDC},
     "capacity_multiplier":       {"num": 0x1D, "size": 2, "unit_conversion": 0x100},
+    "town_production_effect":    {"num": 0x1E, "size": 1},
+    "town_production_multiplier": {"num": 0x1F, "size": 2, "unit_conversion": 0x100},
 }
 # fmt: on
 
