@@ -347,6 +347,8 @@ constant_numbers = {
     # ground sprite IDs
     "GROUNDSPRITE_RAIL_Y"      : 1011,
     "GROUNDSPRITE_RAIL_X"      : 1012,
+    "GROUNDSPRITE_ROAD_Y"      : 1332,
+    "GROUNDSPRITE_ROAD_X"      : 1333,
     "GROUNDSPRITE_CONCRETE"    : 1420,
     "GROUNDSPRITE_CLEARED"     : 3924,
     "GROUNDSPRITE_GRASS_1_3"   : 3943,
@@ -905,6 +907,11 @@ constant_numbers = {
     "TOWNGROWTH_FOOD"                       : 0x0B,
     "TOWNGROWTH_NONE"                       : 0xFF,
 
+    # Town production effect on cargo
+    "TOWNPRODUCTION_PASSENGERS"             : 0x00,
+    "TOWNPRODUCTION_MAIL"                   : 0x02,
+    "TOWNPRODUCTION_NONE"                   : 0xFF,
+
     # Cargo callbacks
     "CARGO_CB_PROFIT"                       : 0x01,
     "CARGO_CB_STATION_RATING"               : 0x02,
@@ -1407,6 +1414,27 @@ settings = {}
 named_parameters = {}
 spritegroups = {"CB_FAILED": "CB_FAILED"}
 
+zoom_levels = {
+    "ZOOM_LEVEL_NORMAL": 0,
+    "ZOOM_LEVEL_IN_4X": 1,
+    "ZOOM_LEVEL_IN_2X": 2,
+    "ZOOM_LEVEL_OUT_2X": 3,
+    "ZOOM_LEVEL_OUT_4X": 4,
+    "ZOOM_LEVEL_OUT_8X": 5,
+}
+
+bit_depths = {"BIT_DEPTH_8BPP": 8, "BIT_DEPTH_32BPP": 32.0}
+
+"""
+Store if there are any 32bpp sprites,
+if so ask to enable the 32bpp blitter via action14
+"""
+any_32bpp_sprites = False
+
+allow_extra_zoom = True
+
+allow_32bpp = True
+
 const_list = [
     (constant_numbers, constant_number),
     (global_parameters, param_from_info),
@@ -1422,6 +1450,8 @@ const_list = [
     (config_flags, config_flag),
     (unified_maglev_var, unified_maglev),
     (spritegroups, create_spritegroup_ref),
+    zoom_levels,
+    bit_depths,
 ]
 
 
