@@ -240,6 +240,7 @@ commands = {
     "CARGO_SHORT":    {"unicode": r"\UE09A\1C", "ascii": r"\9A\1C", "size": 2 * 2},
     "CARGO_TINY":     {"unicode": r"\UE09A\1D", "ascii": r"\9A\1D", "size": 2 * 2},
     "CARGO_NAME":     {"unicode": r"\UE09A\1E", "ascii": r"\9A\1E", "size": 2},
+    "FORCE":          {"unicode": r"\UE09A\21", "ascii": r"\9A\21", "size": 4},
 
     # Colors
     "BLUE":           {"unicode": r"\UE088",    "ascii": r"\88"},
@@ -442,7 +443,7 @@ class StringCommand:
                 return commands[self.name][str_type]
             # Compute position of the argument in the stack.
             stack_pos = 0
-            for (pos, size) in stack:
+            for pos, size in stack:
                 if pos == self.str_pos:
                     break
                 stack_pos += size
