@@ -13,31 +13,37 @@ You should have received a copy of the GNU General Public License along
 with NML; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
 
-import os, sys
+import os
+import sys
+
 
 def get_lib_versions():
     versions = {}
-    #PIL
+    # PIL
     try:
         import PIL
+
         versions["PIL"] = PIL.__version__
     except ImportError:
         versions["PIL"] = "Not found!"
 
-    #PLY
+    # PLY
     try:
         from ply import lex
+
         versions["PLY"] = lex.__version__
     except ImportError:
         versions["PLY"] = "Not found!"
 
     return versions
 
+
 def get_nml_version():
     # First check if this is a git repository, and use that version if available.
     # (unless this is a released tarball, see below)
     try:
         from nml import version_update
+
         version = version_update.get_git_version()
         if version:
             return version
@@ -49,11 +55,13 @@ def get_nml_version():
     # No repository was found. Return the version which was saved upon build.
     try:
         from nml import __version__
+
         version = __version__.version
     except ImportError:
-        version = 'unknown'
+        version = "unknown"
     return version
 
+
 def get_cli_version():
     # Version string for usage in command line
     result = get_nml_version() + "\n\n"
@@ -62,6 +70,7 @@ def get_cli_version():
     result += "nmlc: {}\n".format(nmlc_path)
 
     from nml import lz77
+
     lz77_ver = "C (native)" if lz77.is_native else "Python"
     result += "LZ77 implementation: {}\n\n".format(lz77_ver)
 
